@@ -19,28 +19,39 @@ from models import nin_gc, nin
 
 import quantize
 
+
 def setup_seed(seed):
-    torch.manual_seed(seed)                    
-    #torch.cuda.manual_seed(seed)              
-    torch.cuda.manual_seed_all(seed)           
-    np.random.seed(seed)                       
+    torch.manual_seed(seed)
+    # torch.cuda.manual_seed(seed)
+    torch.cuda.manual_seed_all(seed)
+    np.random.seed(seed)
     torch.backends.cudnn.deterministic = True
 
+
 def save_state(model, best_acc):
     print('==> Saving model ...')
     state = {
-            'best_acc': best_acc,
-            'state_dict': model.state_dict(),
-            }
+        'best_acc': best_acc,
+        'state_dict': model.state_dict(),
+    }
     state_copy = state['state_dict'].copy()
     for key in state_copy.keys():
         if 'module' in key:
             state['state_dict'][key.replace('module.', '')] = \
-                    state['state_dict'].pop(key)
+                state['state_dict'].pop(key)
     if args.model_type == 0:
-        torch.save(state, 'models_save/nin.pth')
+        if args.prune_refine:
+            torch.save({'cfg': cfg, 'best_acc': best_acc,
+                        'state_dict': state['state_dict']}, 'models_save/nin.pth')
+        else:
+            torch.save(state, 'models_save/nin.pth')
     else:
-        torch.save(state, 'models_save/nin_gc.pth')
+        if args.prune_refine:
+            torch.save({'cfg': cfg, 'best_acc': best_acc,
+                        'state_dict': state['state_dict']}, 'models_save/nin_gc.pth')
+        else:
+            torch.save(state, 'models_save/nin_gc.pth')
+
 
 def adjust_learning_rate(optimizer, epoch):
     update_list = [80, 130, 180, 230, 280]
@@ -49,6 +60,7 @@ def adjust_learning_rate(optimizer, epoch):
             param_group['lr'] = param_group['lr'] * 0.1
     return
 
+
 def train(epoch):
     model.train()
 
@@ -58,10 +70,10 @@ def train(epoch):
         data, target = Variable(data), Variable(target)
         output = model(data)
         loss = criterion(output, target)
-        
+
         optimizer.zero_grad()
-        loss.backward()  
-        optimizer.step() 
+        loss.backward()
+        optimizer.step()
 
         if batch_idx % 100 == 0:
             print('Train Epoch: {} [{}/{} ({:.0f}%)]\tLoss: {:.6f}\tLR: {}'.format(
@@ -70,11 +82,11 @@ def train(epoch):
                 optimizer.param_groups[0]['lr']))
     return
 
+
 def test():
     global best_acc
     model.eval()
     test_loss = 0
-    average_test_loss = 0
     correct = 0
 
     for data, target in testloader:
@@ -99,45 +111,46 @@ def test():
     print('Best Accuracy: {:.2f}%\n'.format(best_acc))
     return
 
-if __name__=='__main__':
+
+if __name__ == '__main__':
     parser = argparse.ArgumentParser()
     parser.add_argument('--cpu', action='store_true',
-            help='set if only CPU is available')
+                        help='set if only CPU is available')
     # gpu_id
     parser.add_argument('--gpu_id', action='store', default='',
-            help='gpu_id')
+                        help='gpu_id')
     parser.add_argument('--data', action='store', default='../../../../data',
-            help='dataset path')
+                        help='dataset path')
     parser.add_argument('--lr', action='store', default=0.01,
-            help='the intial learning rate')
+                        help='the intial learning rate')
     parser.add_argument('--wd', action='store', default=1e-5,
-            help='the intial learning rate')
+                        help='the intial learning rate')
     # prune_refine
     parser.add_argument('--prune_refine', default='', type=str, metavar='PATH',
-            help='the path to the prune_refine model')
+                        help='the path to the prune_refine model')
     # refine
     parser.add_argument('--refine', default='', type=str, metavar='PATH',
-            help='the path to the float_refine model')
+                        help='the path to the float_refine model')
     # resume
     parser.add_argument('--resume', default='', type=str, metavar='PATH',
-            help='the path to the resume model')
+                        help='the path to the resume model')
     parser.add_argument('--evaluate', action='store_true',
-            help='evaluate the model')
+                        help='evaluate the model')
     parser.add_argument('--train_batch_size', type=int, default=50)
     parser.add_argument('--eval_batch_size', type=int, default=256)
     parser.add_argument('--num_workers', type=int, default=2)
     parser.add_argument('--start_epochs', type=int, default=1, metavar='N',
-            help='number of epochs to train_start')
+                        help='number of epochs to train_start')
     parser.add_argument('--end_epochs', type=int, default=300, metavar='N',
-            help='number of epochs to train_end')
+                        help='number of epochs to train_end')
     # W/A — bits
     parser.add_argument('--w_bits', type=int, default=8)
     parser.add_argument('--a_bits', type=int, default=8)
     # 模型结构选择
     parser.add_argument('--model_type', type=int, default=1,
-            help='model type:0-nin,1-nin_gc')
+                        help='model type:0-nin,1-nin_gc')
     args = parser.parse_args()
-    print('==> Options:',args)
+    print('==> Options:', args)
 
     if args.gpu_id:
         os.environ["CUDA_VISIBLE_DEVICES"] = args.gpu_id
@@ -153,19 +166,25 @@ if __name__=='__main__':
     transform_test = transforms.Compose([
         transforms.ToTensor(),
         transforms.Normalize((0.4914, 0.4822, 0.4465), (0.2023, 0.1994, 0.2010))])
-    
-    trainset = torchvision.datasets.CIFAR10(root = args.data, train = True, download = True, transform = transform_train)
-    trainloader = torch.utils.data.DataLoader(trainset, batch_size=args.train_batch_size, shuffle=True, num_workers=args.num_workers) # 训练集数据
 
-    testset = torchvision.datasets.CIFAR10(root = args.data, train = False, download = True, transform = transform_test)
-    testloader = torch.utils.data.DataLoader(testset, batch_size=args.eval_batch_size, shuffle=False, num_workers=args.num_workers) # 测试集数据
-    
-    classes = ('plane', 'car', 'bird', 'cat', 'deer', 'dog', 'frog', 'horse', 'ship', 'truck')
+    trainset = torchvision.datasets.CIFAR10(root=args.data, train=True, download=True,
+                                            transform=transform_train)
+    trainloader = torch.utils.data.DataLoader(trainset, batch_size=args.train_batch_size,
+                                              shuffle=True, num_workers=args.num_workers)  # 训练集数据
+
+    testset = torchvision.datasets.CIFAR10(root=args.data, train=False, download=True,
+                                           transform=transform_test)
+    testloader = torch.utils.data.DataLoader(testset, batch_size=args.eval_batch_size,
+                                             shuffle=False, num_workers=args.num_workers)  # 测试集数据
+
+    classes = ('plane', 'car', 'bird', 'cat', 'deer',
+               'dog', 'frog', 'horse', 'ship', 'truck')
 
     if args.prune_refine:
         print('******Prune Refine model******')
         #checkpoint = torch.load('../prune/models_save/nin_refine.pth')
         checkpoint = torch.load(args.prune_refine)
+        cfg = checkpoint['cfg']
         if args.model_type == 0:
             model = nin.Net(cfg=checkpoint['cfg'])
         else:
@@ -211,7 +230,7 @@ if __name__=='__main__':
     print('***ori_model***\n', model)
     quantize.prepare(model, inplace=True, a_bits=args.a_bits, w_bits=args.w_bits)
     print('\n***quant_model***\n', model)
-    
+
     if not args.cpu:
         model.cuda()
         model = torch.nn.DataParallel(model, device_ids=range(torch.cuda.device_count()))
@@ -220,7 +239,7 @@ if __name__=='__main__':
     param_dict = dict(model.named_parameters())
     params = []
     for key, value in param_dict.items():
-        params += [{'params':[value], 'lr': base_lr, 'weight_decay':args.wd}]
+        params += [{'params': [value], 'lr': base_lr, 'weight_decay':args.wd}]
 
     criterion = nn.CrossEntropyLoss()
     optimizer = optim.Adam(params, lr=base_lr, weight_decay=args.wd)
