@@ -23,12 +23,12 @@ class Round(Function):
 class ActivationQuantizer(nn.Module):
     def __init__(self, a_bits):
         super(ActivationQuantizer, self).__init__()
-        self.a_bits = a_bits  
-    
+        self.a_bits = a_bits
+
     # 取整(ste)
     def round(self, input):
         output = Round.apply(input)
-        return output 
+        return output
 
     # 量化/反量化
     def forward(self, input):
@@ -47,12 +47,12 @@ class ActivationQuantizer(nn.Module):
 class WeightQuantizer(nn.Module):
     def __init__(self, w_bits):
         super(WeightQuantizer, self).__init__()
-        self.w_bits = w_bits  
+        self.w_bits = w_bits
 
     # 取整(ste)
     def round(self, input):
         output = Round.apply(input)
-        return output 
+        return output
 
     # 量化/反量化
     def forward(self, input):
@@ -60,7 +60,7 @@ class WeightQuantizer(nn.Module):
             output = input
         elif self.w_bits == 1:
             print('！Binary quantization is not supported ！')
-            assert self.w_bits != 1                      
+            assert self.w_bits != 1
         else:
             output = torch.tanh(input)
             output = output / 2 / torch.max(torch.abs(output)) + 0.5  # 归一化-[0,1]
@@ -70,7 +70,6 @@ class WeightQuantizer(nn.Module):
         return output
 
 
-# ********************* 量化卷积（同时量化A/W，并做卷积） ***********************
 class QuantConv2d(nn.Conv2d):
     def __init__(self,
                  in_channels,
@@ -90,13 +89,14 @@ class QuantConv2d(nn.Conv2d):
         self.quant_inference = quant_inference
         # 实例化调用A和W量化器
         self.activation_quantizer = ActivationQuantizer(a_bits=a_bits)
-        self.weight_quantizer = WeightQuantizer(w_bits=w_bits)      
+        self.weight_quantizer = WeightQuantizer(w_bits=w_bits)
+
     def forward(self, input):
         # 量化A和W
         quant_input = self.activation_quantizer(input)
         quant_input = input
         if not self.quant_inference:
-            quant_weight = self.weight_quantizer(self.weight) 
+            quant_weight = self.weight_quantizer(self.weight)
         else:
             quant_weight = self.weight
         # 量化卷积
@@ -104,6 +104,7 @@ class QuantConv2d(nn.Conv2d):
                           self.groups)
         return output
 
+
 class QuantConvTranspose2d(nn.ConvTranspose2d):
     def __init__(self,
                  in_channels,
@@ -119,11 +120,11 @@ class QuantConvTranspose2d(nn.ConvTranspose2d):
                  a_bits=8,
                  w_bits=8,
                  quant_inference=False):
-        super(QuantConvTranspose2d, self).__init__(in_channels, out_channels, kernel_size, stride, padding, output_padding, 
+        super(QuantConvTranspose2d, self).__init__(in_channels, out_channels, kernel_size, stride, padding, output_padding,
                                                    dilation, groups, bias, padding_mode)
         self.quant_inference = quant_inference
         self.activation_quantizer = ActivationQuantizer(a_bits=a_bits)
-        self.weight_quantizer = WeightQuantizer(w_bits=w_bits) 
+        self.weight_quantizer = WeightQuantizer(w_bits=w_bits)
 
     def forward(self, input):
         quant_input = self.activation_quantizer(input)
@@ -135,13 +136,14 @@ class QuantConvTranspose2d(nn.ConvTranspose2d):
                                     self.groups, self.dilation)
         return output
 
-# ********************* 量化全连接（同时量化A/W，并做卷积） ***********************
+
 class QuantLinear(nn.Linear):
     def __init__(self, in_features, out_features, bias=True, a_bits=8, w_bits=8, quant_inference=False):
         super(QuantLinear, self).__init__(in_features, out_features, bias)
         self.quant_inference = quant_inference
         self.activation_quantizer = ActivationQuantizer(a_bits=a_bits)
-        self.weight_quantizer = WeightQuantizer(w_bits=w_bits)    
+        self.weight_quantizer = WeightQuantizer(w_bits=w_bits)
+
     def forward(self, input):
         quant_input = self.activation_quantizer(input)
         if not self.quant_inference:
@@ -151,6 +153,7 @@ class QuantLinear(nn.Linear):
         output = F.linear(quant_input, quant_weight, self.bias)
         return output
 
+
 def add_quant_op(module, layer_counter, a_bits=8, w_bits=8, quant_inference=False):
     for name, child in module.named_children():
         if isinstance(child, nn.Conv2d):
@@ -158,42 +161,75 @@ def add_quant_op(module, layer_counter, a_bits=8, w_bits=8, quant_inference=Fals
             if layer_counter[0] > 1:
                 if child.bias is not None:
                     quant_conv = QuantConv2d(child.in_channels, child.out_channels,
-                                             child.kernel_size, stride=child.stride, padding=child.padding, dilation=child.dilation, groups=child.groups, bias=True, padding_mode=child.padding_mode, a_bits=a_bits, w_bits=w_bits, quant_inference=quant_inference)
+                                             child.kernel_size, stride=child.stride,
+                                             padding=child.padding, dilation=child.dilation,
+                                             groups=child.groups, bias=True, padding_mode=child.padding_mode,
+                                             a_bits=a_bits, w_bits=w_bits, quant_inference=quant_inference)
                     quant_conv.bias.data = child.bias
                 else:
                     quant_conv = QuantConv2d(child.in_channels, child.out_channels,
-                                             child.kernel_size, stride=child.stride, padding=child.padding, dilation=child.dilation, groups=child.groups, bias=False, padding_mode=child.padding_mode, a_bits=a_bits, w_bits=w_bits, quant_inference=quant_inference)
+                                             child.kernel_size, stride=child.stride,
+                                             padding=child.padding, dilation=child.dilation,
+                                             groups=child.groups, bias=False, padding_mode=child.padding_mode,
+                                             a_bits=a_bits, w_bits=w_bits, quant_inference=quant_inference)
                 quant_conv.weight.data = child.weight
                 module._modules[name] = quant_conv
         elif isinstance(child, nn.ConvTranspose2d):
             layer_counter[0] += 1
             if layer_counter[0] > 1:
                 if child.bias is not None:
-                    quant_conv_transpose = QuantConvTranspose2d(child.in_channels, child.out_channels,
-                                                                child.kernel_size, stride=child.stride, padding=child.padding, output_padding=child.output_padding, dilation=child.dilation, groups=child.groups, bias=True, padding_mode=child.padding_mode, a_bits=a_bits, w_bits=w_bits, quant_inference=quant_inference)
+                    quant_conv_transpose = QuantConvTranspose2d(child.in_channels,
+                                                                child.out_channels,
+                                                                child.kernel_size,
+                                                                stride=child.stride,
+                                                                padding=child.padding,
+                                                                output_padding=child.output_padding,
+                                                                dilation=child.dilation,
+                                                                groups=child.groups,
+                                                                bias=True,
+                                                                padding_mode=child.padding_mode,
+                                                                a_bits=a_bits,
+                                                                w_bits=w_bits,
+                                                                quant_inference=quant_inference)
                     quant_conv_transpose.bias.data = child.bias
                 else:
-                    quant_conv_transpose = QuantConvTranspose2d(child.in_channels, child.out_channels,
-                                                                child.kernel_size, stride=child.stride, padding=child.padding, output_padding=child.output_padding, dilation=child.dilation, groups=child.groups, bias=False, padding_mode=child.padding_mode, a_bits=a_bits, w_bits=w_bits, quant_inference=quant_inference)
+                    quant_conv_transpose = QuantConvTranspose2d(child.in_channels,
+                                                                child.out_channels,
+                                                                child.kernel_size,
+                                                                stride=child.stride,
+                                                                padding=child.padding,
+                                                                output_padding=child.output_padding,
+                                                                dilation=child.dilation,
+                                                                groups=child.groups, bias=False,
+                                                                padding_mode=child.padding_mode,
+                                                                a_bits=a_bits,
+                                                                w_bits=w_bits,
+                                                                quant_inference=quant_inference)
                 quant_conv_transpose.weight.data = child.weight
                 module._modules[name] = quant_conv_transpose
         elif isinstance(child, nn.Linear):
             layer_counter[0] += 1
             if layer_counter[0] > 1:
                 if child.bias is not None:
-                    quant_linear = QuantLinear(child.in_features, child.out_features, bias=True, a_bits=a_bits, w_bits=w_bits, quant_inference=quant_inference)
+                    quant_linear = QuantLinear(child.in_features, child.out_features,
+                                               bias=True, a_bits=a_bits, w_bits=w_bits,
+                                               quant_inference=quant_inference)
                     quant_linear.bias.data = child.bias
                 else:
-                    quant_linear = QuantLinear(child.in_features, child.out_features, bias=False, a_bits=a_bits, w_bits=w_bits, quant_inference=quant_inference)
+                    quant_linear = QuantLinear(child.in_features, child.out_features,
+                                               bias=False, a_bits=a_bits, w_bits=w_bits,
+                                               quant_inference=quant_inference)
                 quant_linear.weight.data = child.weight
                 module._modules[name] = quant_linear
         else:
-            add_quant_op(child, layer_counter, a_bits=a_bits, w_bits=w_bits, quant_inference=quant_inference)
+            add_quant_op(child, layer_counter, a_bits=a_bits, w_bits=w_bits,
+                         quant_inference=quant_inference)
+
 
 def prepare(model, inplace=False, a_bits=8, w_bits=8, quant_inference=False):
     if not inplace:
         model = copy.deepcopy(model)
     layer_counter = [0]
-    add_quant_op(model, layer_counter, a_bits=a_bits, w_bits=w_bits, quant_inference=quant_inference)
+    add_quant_op(model, layer_counter, a_bits=a_bits, w_bits=w_bits,
+                 quant_inference=quant_inference)
     return model
-    
\ No newline at end of file
